"""
Unit tests for the _Moe_di_Stefano_2017 module

TODO: set_moe_di_stefano_settings
TODO: _load_moe_di_stefano_data
TODO: _set_moe_di_stefano_distributions
TODO: Moe_di_Stefano_2017
TODO: _clean_interpolators
TODO: _calculate_multiplicity_fraction
TODO: get_moe_di_stefano_dataset
"""

import unittest

if __name__ == "__main__":
    unittest.main()
